@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 '''
 Advanced Power
-2008-2009(c) Kirill Plyashkevich <ru.spirit@gmail.com>
+2008-2010(c) Kirill Plyashkevich <ru.spirit@gmail.com>
 Connects to bunch of dbus signals, monitors values change and emmits signal in case of update.
 '''
 
@@ -20,11 +20,12 @@ from advpowlib.util.misc import Format, Shell, Sound
 class AbstractAdvancedPower():
 
   app_name= 'Advanced Power'
-  version = '0.4.1'
+  version = '0.4.1-6'
   dev_author = 'Kirill Plyashkevich'
   dev_email = 'ru.spirit@gmail.com'
-  dev_years = '2008-2009'
+  dev_years = '2008-2010'
   apm_iface = 'ru.spirit.advanced_power_monitor'
+  tmp_file = '/tmp/advpow.tmp'
 
   def __init__(self):
 
@@ -84,20 +85,16 @@ class AbstractAdvancedPower():
       self.monitor_uid = 0
       self.queue_recreate_menu()
     self.load_wrappers()
-    self.signals = {'NameOwnerChanged': {'cb':_name_owner_handler, 'signal_name':'NameOwnerChanged', 'dbus_interface':'org.freedesktop.DBus', 'path':'/org/freedesktop/DBus'},
-                    'PropertyModified': {'cb':_property_modified_handler, 'signal_name':'PropertyModified', 'dbus_interface':'ru.spirit.advanced_power_monitor.signal', 'path':'/ru/spirit/advanced_power_monitor'}
-                    }
+    self.signals = {'NameOwnerChanged': {'cb':_name_owner_handler, 'signal_name':'NameOwnerChanged', 'dbus_interface':'org.freedesktop.DBus', 'path':'/org/freedesktop/DBus'}, 'PropertyModified': {'cb':_property_modified_handler, 'signal_name':'PropertyModified', 'dbus_interface':'ru.spirit.advanced_power_monitor.signal', 'path':'/ru/spirit/advanced_power_monitor'}}
     self.init_signals()
     self.menu_cb_map = {'os_version': 'auto',
                         'battery_status': 'auto',
                         'timeleft_active': 'auto',
                         'timeleft_idle': 'auto',
-                        'free_ram': 'auto',
-                        'free_swap': 'auto',
-                        'total_swap': 'auto',
-                        'free_mem': 'auto',
-                        'total_mem': 'auto',
-                        'free_diskspace': 'none',
+                        'ram': 'auto',
+                        'swap': 'auto',
+                        'memory': 'auto',
+                        'diskspace': 'none',
                         'temperature': 'auto',
                         'light_sensor': 'auto',
                         'uptime': 'auto',
@@ -109,19 +106,9 @@ class AbstractAdvancedPower():
                         'usb_mode': 'manual',
                         'run_command': 'none'
                         }
-    self.settings_cb_map = {'play-sounds': self.snd.set,
-                            'temperature-metric': self.queue_recreate_menu,
-                            'use-gtk-theme': self.set_gtk_theme_callback,
-                            'current-theme': self.thm.load,
-                            'use-custom-low-battery-level': self.update_button_state,
-                            'low-battery-level': self.update_button_state
-                           }
-    self.settings_range_map = {'low-battery-level': (1, 25),
-                               'sounds-volume': (0, 100)
-                              }
+    self.settings_cb_map = {'play-sounds': self.snd.set, 'temperature-metric': self.queue_recreate_menu, 'use-gtk-theme': self.set_gtk_theme_callback, 'current-theme': self.thm.load, 'use-custom-low-battery-level': self.update_button_state, 'low-battery-level': self.update_button_state}
+    self.settings_range_map = {'low-battery-level': (1, 25), 'sounds-volume': (0, 100)}
     self.settings_order = ['use-custom-low-battery-level', 'low-battery-level', 'play-sounds', 'use-custom-sounds-volume', 'sounds-volume', 'temperature-metric', 'use-gtk-theme', 'current-theme']
-    self.commands = {'Play sound': 'play-sound'
-                    }
     self.connect('destroy', self._cleanup)
     self.connect('style-set', self.gtk_theme_changed)
     self.create_settings_dialog()
@@ -150,6 +137,10 @@ class AbstractAdvancedPower():
       self.signals[key]['receiver_match'].remove()
     self.destroy_menu()
     self.settings_dialog.destroy()
+    try:
+      os.unlink(self.tmp_file)
+    except:
+      pass
     self.destroy()
 
   def full_subscribe(self):
@@ -245,24 +236,27 @@ class AbstractAdvancedPower():
   def handle_cpu_frequency(self, key):
     return '%s: %s%s' % (Locale.get_item(key), str(self.monitor.get_value(key)), Locale.get('MHz'))
 
-  def handle_free_ram(self, key):
-    return '%s: %s/%s' % (Locale.get_item(key), Format.get_filesize(self.monitor.get_value(key)), Format.get_filesize(self.monitor.get_value('total_ram')))
+  def handle_ram(self, key):
+    ram_info = self.monitor.get_value(key)
+    return '%s: %s/%s' % (Locale.get_item(key), Format.get_filesize(ram_info[1]), Format.get_filesize(ram_info[2]))
 
-  def handle_free_swap(self, key):
-    total = self.monitor.get_value('total_swap')
-    if total == 0:
+  def handle_swap(self, key):
+    swap_info = self.monitor.get_value(key)
+    swap_total = swap_info[2]
+    if swap_total == 0:
       return Locale.get_item('swap_disabled')
     else:
-      return '%s: %s/%s' % (Locale.get_item(key), Format.get_filesize(self.monitor.get_value(key)), Format.get_filesize(total))
+      return '%s: %s/%s' % (Locale.get_item(key), Format.get_filesize(swap_info[1]), Format.get_filesize(swap_total))
 
-  def handle_free_mem(self, key):
-    return '%s: %s/%s' % (Locale.get_item(key), Format.get_filesize(self.monitor.get_value(key)), Format.get_filesize(self.monitor.get_value('total_mem')))
+  def handle_memory(self, key):
+    memory_info = self.monitor.get_value(key)
+    return '%s: %s/%s' % (Locale.get_item(key), Format.get_filesize(memory_info[1]), Format.get_filesize(memory_info[2]))
 
-  def handle_free_diskspace(self, key):
+  def handle_diskspace(self, key):
     tmp = self.monitor.get_value(key)
     result = Locale.get_item('%s_title' % (key))
     for x in tmp:
-      result = '%s\n%s: %s/%s' % (result, x[0], Format.get_filesize(x[1]), Format.get_filesize(x[3]))
+      result = '%s\n%s: %s/%s' % (result, x[0], Format.get_filesize(x[2]), Format.get_filesize(x[3]))
     return result
 
   def handle_device_mode(self, key):
@@ -286,21 +280,15 @@ class AbstractAdvancedPower():
   def update_menu_mode(self, key):
     raise NotImplementedError('AbstractAdvancedPower.update_menu_mode(key) must be implemented')
 
-  def get_cpu_governor(self, key):
-    return self.monitor.get_value(key)
-
   def set_cpu_governor(self, widget=None, governor=''):
     self.monitor.set_cpu_governor(governor)
 
-  def get_bluetooth_mode(self, key):
-    return self.monitor.get_value(key)
+  def set_device_mode(self, widget=None, mode=''):
+    self.monitor.set_device_mode(mode)
 
   def set_bluetooth_mode(self, widget=None, mode=''):
     self.monitor.set_bt_mode(mode)
 
-  def get_usb_mode(self, key):
-    return self.monitor.get_value(key)
-
   def set_usb_mode(self, widget=None, mode=''):
     self.monitor.set_usb_mode(mode)
 #end section
@@ -407,13 +395,16 @@ class AbstractAdvancedPower():
 
 #Special menu items section
   def add_device_mode(self, key):
-    self.add_custom_group(key, [{'type': 'plain', 'key': 'device_lock', 'action': self.call_tklock_device}, {'type': 'upd_item', 'key': 'device_mode', 'actions': {'activate': self.switch_device_mode}}, {'type': 'plain', 'key': 'reboot', 'action': self.call_reboot}, {'type': 'plain', 'key': 'shutdown', 'action': self.call_shutdown}])
+    def flight_and_lock(widget=None):
+      self.set_device_mode(widget, 'flight')
+      self.call_tklock_device(widget)
+    self.add_custom_group(key, [{'type': 'plain', 'key': 'device_lock', 'action': self.call_tklock_device}, {'type': 'upd_item', 'key': 'device_mode', 'actions': {'activate': self.switch_device_mode}}, {'type': 'plain', 'key': 'device_mode_flight_and_lock', 'action': flight_and_lock}, {'type': 'plain', 'key': 'reboot', 'action': self.call_reboot}, {'type': 'plain', 'key': 'shutdown', 'action': self.call_shutdown}])
 
   def add_buttons_emulation(self, key):
     self.add_custom_group(key, [{'type': 'plain', 'key': 'buttons-emu-home-p', 'action': self.home_key_p}, {'type': 'plain', 'key': 'buttons-emu-home-lp', 'action': self.home_key_pl}])
 
-  def add_free_diskspace(self, key):
-    self.add_custom_group(key, [{'type': 'upd_item', 'key': 'free_diskspace', 'actions': {}}])
+  def add_diskspace(self, key):
+    self.add_custom_group(key, [{'type': 'upd_item', 'key': 'diskspace', 'actions': {}}])
 
   def add_custom_group(self, menu_text, items):
     raise NotImplementedError('AbstractAdvancedPower.add_custom_group(menu_text, items) must be implemented')
@@ -435,6 +426,7 @@ class AbstractAdvancedPower():
 
   def show_run_command(self, widget=None, key='run_command'):
     commandline = ''
+    su_prefix = ''
     dialog = gtk.Dialog(self.app_name, None, gtk.DIALOG_MODAL | gtk.DIALOG_NO_SEPARATOR, (gtk.STOCK_OK, gtk.RESPONSE_OK, gtk.STOCK_CANCEL, gtk.RESPONSE_NONE))
     input_field = gtk.Entry()
     in_terminal = gtk.CheckButton()
@@ -444,18 +436,24 @@ class AbstractAdvancedPower():
     dialog.vbox.pack_start(hildon.Caption(value=('%s:' % Locale.get_item('%s_as_root' % (key))), control=as_root, flag=1, icon=gtk.Image(), group=gtk.SizeGroup(0)), fill=True)
     dialog.show_all()
     response = dialog.run()
-    run_in_terminal = in_terminal.get_active()
-    if run_in_terminal:
-      commandline = '%sosso-xterm \'' % commandline
+
+    commandline = input_field.get_text()
+    banner_text = commandline
+    script = '#!/bin/sh\n%s' % (commandline)
+
     if as_root.get_active():
-      commandline = '%ssudo ' % commandline
-    commandline = '%s%s' % (commandline, input_field.get_text())
-    if run_in_terminal:
-      commandline = '%s && read\'' % commandline
+      su_prefix = 'sudo '
+    commandline = '%s%s' % (su_prefix, self.tmp_file)
+
+    if in_terminal.get_active():
+      script = '%s\nread x' % (script)
+      commandline = '/usr/bin/osso-xterm \'%s\'' % (commandline)
+
     dialog.hide()
     dialog.destroy()
     if response == gtk.RESPONSE_OK and commandline != '':
-      self.info_banner = Banner.show_animation(self, '%s %s' % (Locale.get('starting'), commandline), self.info_banner)
+      self.info_banner = Banner.show_animation(self, '%s %s' % (Locale.get('starting'), banner_text), self.info_banner)
+      Shell.run_command('echo "%s" > %s && chmod 777 %s' % (script, self.tmp_file, self.tmp_file))
       Shell.run_command_async(commandline, self.info_banner)
 #      Shell.run_command(commandline)
 #end section
