@@ -3,9 +3,10 @@ from advanced_power import *
 
 def main():
   p = hd_plugin_get_objects()[0]#AdvancedPowerMaemo4()
-  p.show_settings_dialog()
-  p.settings_dialog.run()
-  p.create_menu()
+#  p.show_settings_dialog()
+#  p.settings_dialog.run()
+#  p.create_menu()
+#  p.show_run_command()
   time.sleep(1.0)
   p.destroy()
 
